==> dash-3.5.0-sources.jar: cz/cuni/amis/dash/DashSensePresenter.java <==
package cz.cuni.amis.dash;

import cz.cuni.amis.pogamut.sposh.dbg.engine.IDebugEngine;
import cz.cuni.amis.pogamut.sposh.elements.*;
import cz.cuni.pogamut.shed.presenter.ShedPresenter;
import cz.cuni.pogamut.shed.widget.ShedScene;
import cz.cuni.pogamut.shed.widget.ShedVariableWidget;

/**
 * Presenter used by Dash to present {@link Sense}.
 *
 * @see DashPrimitivePresenter Presenter with functionality common to {@link TriggeredAction}
 * and {@link Sense}.
 * @author Honza
 */
public class DashSensePresenter extends DashPrimitivePresenter<Sense> {

    public DashSensePresenter(IDebugEngine engine, LapPath primitivePath, ShedScene scene, ShedPresenter presenter, Sense primitive, ShedVariableWidget primitiveWidget, LapChain primitiveChain) {
        super(engine, primitivePath, scene, presenter, primitive, primitiveWidget, primitiveChain);
    }

    /**
     * Get title text to be displayed in ther widget. It uses mapped name, i.e.
     * it takes information from {@link PrimitiveInfo} of the presented {@link Sense}
     * and combines it with predicate and operand of the {@link Sense}.
     *
     * @return Mapped name, if exists, FQN otherwise
     */
    @Override
    protected String getTitleText() {
        String mappedName = presenter.getNameMapping(primitive.getName());
        if (mappedName == null) {
            mappedName = primitive.getName();
        }
        Object operand = primitive.getOperand();
        Sense.Predicate predicate = primitive.getPredicate();

        String senseRepresentation;
        if (predicate.equals(Sense.Predicate.DEFAULT) && Boolean.TRUE.equals(operand)) {
            return mappedName;
        } else {
            String operandString = Result.toLap(operand);
            senseRepresentation = mappedName + predicate.toString() + operandString;
            return senseRepresentation;
        }
    }
}

==> dash-3.5.1-20130412.041846-59-sources.jar: cz/cuni/amis/dash/DashSensePresenter.java <==
package cz.cuni.amis.dash;

import cz.cuni.amis.pogamut.sposh.dbg.engine.IDebugEngine;
import cz.cuni.amis.pogamut.sposh.elements.*;
import cz.cuni.pogamut.shed.presenter.ShedPresenter;
import cz.cuni.pogamut.shed.widget.ShedScene;
import cz.cuni.pogamut.shed.widget.ShedVariableWidget;

/**
 * Presenter used by Dash to present {@link Sense}.
 *
 * @see DashPrimitivePresenter Presenter with functionality common to {@link TriggeredAction}
 * and {@link Sense}.
 * @author Honza
 */
class DashSensePresenter extends DashPrimitivePresenter<Sense> {

    public DashSensePresenter(IDebugEngine engine, LapPath primitivePath, ShedScene scene, ShedPresenter presenter, Sense primitive, ShedVariableWidget primitiveWidget, LapChain primitiveChain) {
        super(engine, primitivePath, scene, presenter, primitive, primitiveWidget, primitiveChain);
    }

    /**
     * Get title text to be displayed in ther widget. It uses mapped name, i.e.
     * it takes information from {@link PrimitiveInfo} of the presented {@link Sense}
     * and combines it with predicate and operand of the {@link Sense}.
     *
     * @return Mapped name, if exists, FQN otherwise
     */
    @Override
    protected String getTitleText() {
        String mappedName = presenter.getNameMapping(primitive.getName());
        if (mappedName == null) {
            mappedName = primitive.getName();
        }
        Object operand = primitive.getOperand();
        Sense.Predicate predicate = primitive.getPredicate();

        String senseRepresentation;
        if (predicate.equals(Sense.Predicate.DEFAULT) && Boolean.TRUE.equals(operand)) {
            return mappedName;
        } else {
            String operandString = Result.toLap(operand);
            senseRepresentation = mappedName + predicate.toString() + operandString;
            return senseRepresentation;
        }
    }
}
